@@ -63,7 +63,7 @@ static inline void php_http_querystring_str(zval *instance, zval *return_value)
 	}
 }
 
-static inline void php_http_querystring_get(zval *instance, int type, char *name, uint name_len, zval *defval, zend_bool del, zval *return_value)
+static inline void php_http_querystring_get(zval *instance, int type, char *name, uint32_t name_len, zval *defval, zend_bool del, zval *return_value)
 {
 	zval *arrval, qarray_tmp, *qarray = zend_read_property(php_http_querystring_class_entry, instance, ZEND_STRL("queryArray"), 0, &qarray_tmp);
 
@@ -98,22 +98,22 @@ ZEND_RESULT_CODE php_http_querystring_xlate(zval *dst, zval *src, const char *ie
 	zval *entry;
 	zend_string *xkey, *xstr;
 	php_http_arrkey_t key;
-	
+
 	ZEND_HASH_FOREACH_KEY_VAL(Z_ARRVAL_P(src), key.h, key.key, entry)
 	{
 		if (key.key) {
 			if (PHP_ICONV_ERR_SUCCESS != php_iconv_string(key.key->val, key.key->len, &xkey, oe, ie)) {
-				php_error_docref(NULL, E_WARNING, "Failed to convert '%.*s' from '%s' to '%s'", key.key->len, key.key->val, ie, oe);
+				php_error_docref(NULL, E_WARNING, "Failed to convert '%.*s' from '%s' to '%s'", (int) key.key->len, key.key->val, ie, oe);
 				return FAILURE;
 			}
 		}
-		
+
 		if (Z_TYPE_P(entry) == IS_STRING) {
 			if (PHP_ICONV_ERR_SUCCESS != php_iconv_string(Z_STRVAL_P(entry), Z_STRLEN_P(entry), &xstr, oe, ie)) {
 				if (key.key) {
 					zend_string_release(xkey);
 				}
-				php_error_docref(NULL, E_WARNING, "Failed to convert '%.*s' from '%s' to '%s'", Z_STRLEN_P(entry), Z_STRVAL_P(entry), ie, oe);
+				php_error_docref(NULL, E_WARNING, "Failed to convert '%.*s' from '%s' to '%s'", (int) Z_STRLEN_P(entry), Z_STRVAL_P(entry), ie, oe);
 				return FAILURE;
 			}
 			if (key.key) {
@@ -123,7 +123,7 @@ ZEND_RESULT_CODE php_http_querystring_xlate(zval *dst, zval *src, const char *ie
 			}
 		} else if (Z_TYPE_P(entry) == IS_ARRAY) {
 			zval subarray;
-			
+
 			array_init(&subarray);
 			if (key.key) {
 				add_assoc_zval_ex(dst, xkey->val, xkey->len, &subarray);
@@ -137,7 +137,7 @@ ZEND_RESULT_CODE php_http_querystring_xlate(zval *dst, zval *src, const char *ie
 				return FAILURE;
 			}
 		}
-		
+
 		if (key.key) {
 			zend_string_release(xkey);
 		}
@@ -357,7 +357,7 @@ PHP_METHOD(HttpQueryString, __construct)
 {
 	zval *params = NULL;
 	zend_error_handling zeh;
-	
+
 	php_http_expect(SUCCESS == zend_parse_parameters(ZEND_NUM_ARGS(), "|z", &params), invalid_arg, return);
 
 	zend_replace_error_handling(EH_THROW, php_http_get_exception_bad_querystring_class_entry(), &zeh);
@@ -370,25 +370,28 @@ ZEND_END_ARG_INFO();
 PHP_METHOD(HttpQueryString, getGlobalInstance)
 {
 	zval *instance, *_GET;
-	zend_string *zs;
 
 	php_http_expect(SUCCESS == zend_parse_parameters_none(), invalid_arg, return);
 
-	zs = zend_string_init(ZEND_STRL("instance"), 0);
-	instance = zend_std_get_static_property(php_http_querystring_class_entry, zs, 0);
-	zend_string_release(zs);
+	instance = zend_read_static_property(php_http_querystring_class_entry, ZEND_STRL("instance"), 0);
 
 	if (Z_TYPE_P(instance) == IS_OBJECT) {
 		RETVAL_ZVAL(instance, 1, 0);
 	} else if ((_GET = php_http_env_get_superglobal(ZEND_STRL("_GET")))) {
+		zval tmp, *qa;
+
 		ZVAL_OBJ(return_value, php_http_querystring_object_new(php_http_querystring_class_entry));
 
-		ZVAL_MAKE_REF(_GET);
-		zend_update_property(php_http_querystring_class_entry, return_value, ZEND_STRL("queryArray"), _GET);
+		ZVAL_STRING(&tmp, "queryArray");
+		qa = Z_OBJ_HT_P(return_value)->get_property_ptr_ptr(return_value, &tmp, BP_VAR_RW, NULL);
+		zval_ptr_dtor(&tmp);
+
+		ZVAL_NEW_REF(_GET, _GET);
+		ZVAL_COPY(qa, _GET);
 
 		zend_update_static_property(php_http_querystring_class_entry, ZEND_STRL("instance"), return_value);
 	} else {
-		php_http_throw(unexpected_val, "Could not acquire reference to superglobal GET array", NULL);
+		php_http_throw(unexpected_val, "Could not acquire reference to superglobal GET array");
 	}
 
 }
@@ -444,7 +447,7 @@ PHP_METHOD(HttpQueryString, get)
 	zend_long type = 0;
 	zend_bool del = 0;
 	zval *ztype = NULL, *defval = NULL;
-	
+
 	if (SUCCESS == zend_parse_parameters(ZEND_NUM_ARGS(), "|szzb", &name_str, &name_len, &ztype, &defval, &del)) {
 		if (name_str && name_len) {
 			if (ztype) {
@@ -452,7 +455,7 @@ PHP_METHOD(HttpQueryString, get)
 					type = Z_LVAL_P(ztype);
 				} else if(Z_TYPE_P(ztype) == IS_STRING) {
 					switch (Z_STRVAL_P(ztype)[0]) {
-						case 'B': 
+						case 'B':
 						case 'b':	type = PHP_HTTP_QUERYSTRING_TYPE_BOOL;		break;
 						case 'L':
 						case 'l':
@@ -461,7 +464,7 @@ PHP_METHOD(HttpQueryString, get)
 						case 'd':
 						case 'D':
 						case 'F':
-						case 'f':	type = PHP_HTTP_QUERYSTRING_TYPE_FLOAT;		break;	
+						case 'f':	type = PHP_HTTP_QUERYSTRING_TYPE_FLOAT;		break;
 						case 'S':
 						case 's':	type = PHP_HTTP_QUERYSTRING_TYPE_STRING;	break;
 						case 'A':
@@ -484,11 +487,11 @@ ZEND_END_ARG_INFO();
 PHP_METHOD(HttpQueryString, set)
 {
 	zval *params;
-	
+
 	if (SUCCESS != zend_parse_parameters(ZEND_NUM_ARGS(), "z", &params)) {
 		return;
 	}
-	
+
 	php_http_querystring_set(getThis(), params, QS_MERGE);
 	RETVAL_ZVAL(getThis(), 1, 0);
 }
@@ -502,7 +505,7 @@ PHP_METHOD(HttpQueryString, mod)
 	zend_error_handling zeh;
 
 	php_http_expect(SUCCESS == zend_parse_parameters(ZEND_NUM_ARGS(), "z", &params), invalid_arg, return);
-	
+
 	zend_replace_error_handling(EH_THROW, php_http_get_exception_bad_querystring_class_entry(), &zeh);
 	ZVAL_OBJ(return_value, Z_OBJ_HT_P(instance)->clone_obj(instance));
 	/* make sure we do not inherit the reference to _GET */
@@ -559,7 +562,7 @@ PHP_METHOD(HttpQueryString, xlate)
 
 	php_http_querystring_set(getThis(), &na, 0);
 	RETVAL_ZVAL(getThis(), 1, 0);
-	
+
 	zval_ptr_dtor(&na);
 }
 #endif /* HAVE_ICONV */
@@ -603,8 +606,8 @@ PHP_METHOD(HttpQueryString, offsetGet)
 	if (SUCCESS != zend_parse_parameters(ZEND_NUM_ARGS(), "S", &offset)) {
 		return;
 	}
-	
 	qa = zend_read_property(php_http_querystring_class_entry, getThis(), ZEND_STRL("queryArray"), 0, &qa_tmp);
+
 	ZVAL_DEREF(qa);
 
 	if (Z_TYPE_P(qa) == IS_ARRAY) {
@@ -622,7 +625,7 @@ PHP_METHOD(HttpQueryString, offsetSet)
 {
 	zend_string *offset;
 	zval *value, param, znull;
-	
+
 	if (SUCCESS != zend_parse_parameters(ZEND_NUM_ARGS(), "Sz", &offset, &value)) {
 		return;
 	}
@@ -650,8 +653,8 @@ PHP_METHOD(HttpQueryString, offsetExists)
 	if (SUCCESS != zend_parse_parameters(ZEND_NUM_ARGS(), "S", &offset)) {
 		return;
 	}
-	
 	qa = zend_read_property(php_http_querystring_class_entry, getThis(), ZEND_STRL("queryArray"), 0, &qa_tmp);
+
 	ZVAL_DEREF(qa);
 
 	if (Z_TYPE_P(qa) == IS_ARRAY) {
@@ -669,7 +672,7 @@ PHP_METHOD(HttpQueryString, offsetUnset)
 {
 	zend_string *offset;
 	zval param, znull;
-	
+
 	if (SUCCESS != zend_parse_parameters(ZEND_NUM_ARGS(), "S", &offset)) {
 		return;
 	}
@@ -682,7 +685,7 @@ PHP_METHOD(HttpQueryString, offsetUnset)
 }
 
 static zend_function_entry php_http_querystring_methods[] = {
-	PHP_ME(HttpQueryString, __construct, ai_HttpQueryString___construct, ZEND_ACC_PUBLIC|ZEND_ACC_CTOR|ZEND_ACC_FINAL)
+	PHP_ME(HttpQueryString, __construct, ai_HttpQueryString___construct, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
 
 	PHP_ME(HttpQueryString, toArray, ai_HttpQueryString_toArray, ZEND_ACC_PUBLIC)
 	PHP_ME(HttpQueryString, toString, ai_HttpQueryString_toString, ZEND_ACC_PUBLIC)
